#include <stdio.h>
#include <stdlib.h>
#include <libpq-fe.h>

void do_exit(PGconn *conn) {
  fprintf(stderr, "%s\n", PQerrorMessage(conn));
  /*close connection and free memory*/
  PQfinish(conn);
  exit(EXIT_FAILURE);
}

int main(int argc, char **argv) {
  /*declaration*/
  const char *conninfo;
  
  printf("main() Started...\n");

  /*read command line*/
  if (argc > 1){
    printf("main() argv[1]: %s\n", argv[1]);
    conninfo = argv[1];
  }else{
    printf("call ./main <connection info>\n");
    return 1;
  }

  /*connect to database*/
  PGconn *conn = PQconnectdb(conninfo);

  if (PQstatus(conn) == CONNECTION_BAD) {
    fprintf(stderr, "Connection to database failed: %s\n",
            PQerrorMessage(conn));
    do_exit(conn);
  }else if(PQstatus(conn)==CONNECTION_OK){
    printf("main() connected to database\n");
  }else{
    printf("main() connection status NOT known\n");
  }

  char *user = PQuser(conn);
  char *db_name = PQdb(conn);
  char *pswd = PQpass(conn);
  printf("User: %s\n", user);
  printf("Database name: %s\n", db_name);
  printf("Password: %s\n", pswd);

    /*return integer representing database version*/
  int ver = PQserverVersion(conn);
  printf("Server version: %d\n", ver);

  PQfinish(conn);
  return 0;
}
